<?php
// Enable error reporting for debugging during development
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

// Path to cookies file
$dataFile = 'cookies.json';

// Load cookies data if file exists
$data = file_exists($dataFile) ? json_decode(file_get_contents($dataFile), true) : [];

$email = isset($_GET['email']) ? $_GET['email'] : null;
$auth_session = null;

// Validate email and check if it exists in the cookies file
if ($email && isset($data[$email])) {
    $auth_session = $data[$email]['cookie'];
} else {
    echo json_encode(['error' => 'Email not found']);
    exit;
}

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $uuid = isset($_POST['uuid']) ? trim($_POST['uuid']) : '';

    // Validate the UUID
    if (empty($uuid)) {
        echo json_encode(['error' => 'UUID is required']);
        exit;
    }

    // Escape the UUID for JSON safety
    $escaped_uuid = addslashes($uuid);

    // Initialize cURL
    $curl = curl_init();

    curl_setopt_array($curl, [
        CURLOPT_URL => 'https://stablediffusionweb.com/api/generate.image.getTasks?batch=1',
        CURLOPT_RETURNTRANSFER => true,
        CURLOPT_ENCODING => '',
        CURLOPT_MAXREDIRS => 10,
        CURLOPT_TIMEOUT => 30,
        CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
        CURLOPT_CUSTOMREQUEST => 'POST',
        CURLOPT_POSTFIELDS => '{"0":{"json":[{"uuid":"' . $escaped_uuid . '","status":"processing","error_code":"None"}]}}',
        CURLOPT_COOKIE => 'NEXT_LOCALE=en; auth_session=' . $auth_session,
        CURLOPT_HTTPHEADER => [
            'User-Agent: Mozilla/5.0 (Linux; Android 10; Zenfone Max Pro M1 Build/QQ3A.200805.001) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/131.0.6778.135 Mobile Safari/537.36',
            'Accept-Encoding: gzip, deflate, br, zstd',
            'Content-Type: application/json',
            'sec-ch-ua-platform: "Android"',
            'sec-ch-ua' => '"Android WebView";v="131", "Chromium";v="131", "Not_A Brand";v="24"',
            'sec-ch-ua-mobile' => '?1',
            'origin' => 'https://stablediffusionweb.com',
            'x-requested-with' => 'mark.via.gp',
            'sec-fetch-site' => 'same-origin',
            'sec-fetch-mode' => 'cors',
            'sec-fetch-dest' => 'empty',
            'referer' => 'https://stablediffusionweb.com/app/image-generator',
            'accept-language' => 'en-US,en;q=0.9',
            'priority' => 'u=1, i',
        ],
    ]);

    $response = curl_exec($curl);
    $err = curl_error($curl);
    $http_code = curl_getinfo($curl, CURLINFO_HTTP_CODE);

    curl_close($curl);

    // Handle cURL errors
    if ($err) {
        echo json_encode(['error' => 'cURL Error #: ' . $err]);
        exit;
    }

    // Handle non-200 HTTP responses
    if ($http_code !== 200) {
        echo json_encode(['error' => 'HTTP Error Code: ' . $http_code, 'response' => $response]);
        exit;
    }

    // Output successful response
    echo $response;
} elseif ($_SERVER['REQUEST_METHOD'] === 'GET') {
    // Handle GET requests
    echo json_encode(['error' => 'Invalid Request Method: POST request needed']);
} else {
    // Handle unsupported HTTP methods
    echo json_encode(['error' => 'Unsupported Request Method']);
}
?>
