addEventListener('fetch', event => {
  event.respondWith(handleRequest(event.request));
});
async function handleRequest(request) {
  if (request.method === 'OPTIONS') {
    // Handle CORS preflight request
    return new Response(null, {
      headers: {
        'Access-Control-Allow-Origin': '*',
        'Access-Control-Allow-Methods': 'POST, OPTIONS',
        'Access-Control-Allow-Headers': 'Content-Type, xi-api-key, User-Agent, CF-Connecting-IP'
      }
    });
  }

  if (request.method !== 'POST') {
    return new Response(JSON.stringify({ error: 'Method not allowed' }), { status: 405 });
  }

  try {
    const requestData = await request.json();
    const text = requestData.text;
    const narratorId = requestData.narratorId || 'bIHbv24MWmeRgasZH58o';

    const apiUrl = `https://api.elevenlabs.io/v1/text-to-speech/${narratorId}?allow_unauthenticated=1`;

    const currentTime = new Date().toISOString().replace('T', ' ').split('.')[0]; // Format: 2024-10-25 09:58:18
    const contentLength = JSON.stringify(requestData).length;

    const apiResponse = await fetch(apiUrl, {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json',
      },
      body: JSON.stringify({
        text: text,
        model_id: 'eleven_multilingual_v2'
      })
    });

    const headers = new Headers(apiResponse.headers);
    headers.set('Access-Control-Allow-Origin', '*');

    return new Response(apiResponse.body, {
      headers: headers,
      status: apiResponse.status
    });
  } catch (error) {
    return new Response(JSON.stringify({ error: 'Internal Server Error' }), {
      status: 500,
      headers: { 'Content-Type': 'application/json' }
    });
  }
}