<?php

$uploadDir = 'uploads'; // Directory to store files
if (!is_dir($uploadDir)) {
    mkdir($uploadDir, 0777, true);
}

// Handle file deletion
if ($_SERVER['REQUEST_METHOD'] === 'GET' && isset($_GET['delete'])) {
    $fileToDelete = $uploadDir . '/' . basename($_GET['delete']);
    if (file_exists($fileToDelete)) {
        if (unlink($fileToDelete)) {
            $message = "File '" . basename($_GET['delete']) . "' deleted successfully!";
        } else {
            $message = "Error deleting file.";
        }
    } else {
        $message = "File not found.";
    }
}

// Handle file saving
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['filename']) && isset($_POST['content'])) {
    $filename = trim($_POST['filename']);
    $content = $_POST['content'];

    // Sanitize filename for potentially unsafe characters, but *allow* spaces temporarily
    $safeFilename = preg_replace('/[^a-zA-Z0-9._ -]/', '', $filename);

    // Generate a timestamp for file name
    $timestamp = date('Ymd_His');

    if (!empty($filename) && !empty($content)) {
        // Convert spaces to underscores for saving (use the *safe* filename)
        $baseFilename = str_replace(' ', '_', $safeFilename) . '_' . $timestamp;
        $filepath = $uploadDir . '/' . $baseFilename . '.txt'; // Add .txt extension with timestamp
        $counter = 1;
        //check for existing file if so add counter at the end
        while (file_exists($filepath)) {
            $filepath = $uploadDir . '/' . str_replace(' ', '_', $baseFilename) . '_' . $counter . '.txt';
            $counter++;
        }

        if (file_put_contents($filepath, $content) !== false) {
             // Get the file modification time and format it
            $fileModificationTime = date('h:iA_/_d-F-Y', filemtime($filepath));
            $message = "File '" . $filename . "' saved successfully on ". $fileModificationTime."!";
        } else {
            $message = "Error saving file.";
        }
    } else {
        $message = "Filename and content cannot be empty";
    }
}

// Read the list of files and content if a file is selected
$files = [];
$selectedFileContent = '';
$selectedFileName = '';
if (is_dir($uploadDir)) {
    $filelist = glob($uploadDir . '/*.txt');
    if ($filelist) {
        // Sort files by modification time, newest first
        usort($filelist, function($a, $b) {
            return filemtime($b) - filemtime($a);
        });

        foreach ($filelist as $file) {
            $files[] = basename($file);
        }
        if (isset($_GET['file'])) {
          $selectedFileName =  $_GET['file'];

            //remove time stamp and counter from name
             $selectedFileName = preg_replace('/_\d{8}_\d{6}(_\d+)?\.txt$/', '',  $selectedFileName);
            $selectedFile = $uploadDir . '/' . $_GET['file'];
            if (file_exists($selectedFile)) {
                $selectedFileContent = htmlspecialchars(file_get_contents($selectedFile));
            }
        }
    }
}

?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Text File Manager</title>
    <style>
        body {
            font-family: 'Segoe UI', Tahoma, Geneva, Verdana, sans-serif;
            background-color: #ecf0f3;
            color: #333;
            margin: 20px;
            padding: 20px;
            display: flex;
            flex-direction: column;
            align-items: center;
        }

        h1 {
            color: #5e81ac;
            text-align: center;
            margin-bottom: 30px;
        }

        form {
            background-color: #ecf0f3;
            padding: 30px;
            border-radius: 10px;
            box-shadow:  13px 13px 20px #cbced1,
                         -13px -13px 20px #ffffff;
            width: 80vw;
            max-width: 800px;
            margin-bottom: 30px;
            display: flex;
            flex-direction: column;
            align-items: center;
        }

        form > div {
            width: 100%;
            display: flex;
            flex-direction: column;
            margin-bottom: 15px;
        }

        label {
            display: block;
            margin-bottom: 8px;
            color: #777;
            font-weight: bold;
        }

        input[type="text"] {
            padding: 12px;
            border: none;
            border-radius: 6px;
            width: calc(100% - 24px); /* Adjusted width for padding */
            margin-bottom: 15px;
            box-sizing: border-box;
            background: #ecf0f3;
            box-shadow: inset 6px 6px 6px #cbced1,
                        inset -6px -6px 6px #ffffff;
            color: #555;
        }

        textarea {
            width: calc(100% - 5px); /* Adjusted width for padding */
            height: 350px;
            padding: 12px;
            border: none;
            border-radius: 6px;
            box-sizing: border-box;
            margin-bottom: 15px;
            font-family: monospace;
            background: #ecf0f3;
            box-shadow: inset 6px 6px 6px #cbced1,
                        inset -6px -6px 6px #ffffff;
            color: #555;
            resize: vertical;
        }

        button {
            background-color: #5e81ac;
            color: white;
            padding: 12px 20px;
            border: none;
            border-radius: 6px;
            cursor: pointer;
            transition: background-color 0.3s, transform 0.2s, box-shadow 0.2s;
            margin: 5px 0;
            box-shadow: 4px 4px 8px #cbced1,
                        -4px -4px 8px #ffffff;
        }

        button:hover {
            background-color: #4c566a;
            transform: translateY(-2px);
            box-shadow: 6px 6px 12px #cbced1,
                        -6px -6px 12px #ffffff;
        }

        ul {
            list-style: none;
            padding: 0;
            width: 80vw;
            max-width: 800px;
        }

        ul li {
            margin: 10px 0;
            padding: 12px;
            border-radius: 8px;
            background-color: #ecf0f3;
            box-shadow: 6px 6px 10px #cbced1,
                        -6px -6px 10px #ffffff;
            display: flex;
            justify-content: space-between;
            align-items: center;
            transition: transform 0.2s, box-shadow 0.2s;
        }

        ul li:hover {
            transform: translateY(-3px);
            box-shadow: 8px 8px 14px #cbced1,
                        -8px -8px 14px #ffffff;
        }

        ul li a {
            text-decoration: none;
            color: #5e81ac;
            display: block;
            flex-grow: 1;
            transition: color 0.3s;
        }

        ul li a:hover {
            color: #4c566a;
        }

        .error-message {
            color: #bf616a;
            margin-top: 10px;
            text-align: center;
        }

        .success-message {
            color: #a3be8c;
            margin-top: 10px;
            text-align: center;
        }

        .delete-btn {
            background-color: #bf616a;
            color: white;
            padding: 8px 12px;
            border: none;
            border-radius: 6px;
            cursor: pointer;
            transition: background-color 0.3s, transform 0.2s, box-shadow 0.2s;
            box-shadow: 3px 3px 6px #cbced1,
                        -3px -3px 6px #ffffff;
        }

        .delete-btn:hover {
            background-color: #962e2e;
            transform: translateY(-1px);
            box-shadow: 4px 4px 8px #cbced1,
                        -4px -4px 8px #ffffff;
        }
        /* Neomorphic Styles */
        .neomorphic-input {
            border: none;
            background: #ecf0f3;
            box-shadow: inset 6px 6px 6px #cbced1,
                        inset -6px -6px 6px #ffffff;
            padding: 10px;
            border-radius: 5px;
            color: #555;
        }

        .neomorphic-input:focus {
            outline: none;
            box-shadow: inset 8px 8px 8px #cbced1,
                        inset -8px -8px 8px #ffffff;
        }

        .neomorphic-button {
             background-color: #5e81ac;
            color: white;
            padding: 12px 20px;
            border: none;
            border-radius: 6px;
            cursor: pointer;
            transition: background-color 0.3s, transform 0.2s, box-shadow 0.2s;
            margin: 5px 0;
            box-shadow: 4px 4px 8px #cbced1,
                        -4px -4px 8px #ffffff;
        }

        .neomorphic-button:hover {
            background-color: #4c566a;
            transform: translateY(-2px);
            box-shadow: 6px 6px 12px #cbced1,
                        -6px -6px 12px #ffffff;
        }

        .copy-btn, .paste-btn {
            background-color: #a3be8c;
            color: white;
            padding: 8px 12px;
            border: none;
            border-radius: 6px;
            cursor: pointer;
            transition: background-color 0.3s, transform 0.2s, box-shadow 0.2s;
            box-shadow: 3px 3px 6px #cbced1,
                        -3px -3px 6px #ffffff;
             margin-left: 10px;
        }

        .copy-btn:hover, .paste-btn:hover {
            background-color: #91a875;
            transform: translateY(-1px);
            box-shadow: 4px 4px 8px #cbced1,
                        -4px -4px 8px #ffffff;
        }

        .paste-btn {
            background-color: #88c0d0; /* Different color for paste */
        }

        .paste-btn:hover {
            background-color: #73a2b1;
        }
    </style>
</head>
<body>

    <form id="fileForm" method="POST">
        <div>
            <label for="filename">File Name:</label>
            <div style="display: block; align-items: center;">
                <input type="text" name="filename" id="filename" value="<?php echo htmlspecialchars(str_replace('.txt', '', $selectedFileName)); ?>" required class="neomorphic-input">
                <button type="button" class="copy-btn" onclick="copyToClipboard('filename', true)">Copy Name</button>
                <button type="button" class="paste-btn" onclick="pasteFromClipboard('filename')">Paste Name</button>
            </div>
        </div>
        <div>
            <label for="content">File Content:</label>
            <div style="display: block; align-items: center;">
                <button type="button" class="copy-btn" onclick="copyToClipboard('content', false)">Copy Content</button>
                <button type="button" class="paste-btn" onclick="pasteFromClipboard('content')">Paste Content</button>
                <textarea name="content" id="content" required class="neomorphic-input"><?php echo $selectedFileContent ?></textarea>
            </div>
        </div>
        <button type="submit" class="neomorphic-button">Save File</button>
        <?php if (isset($message)) : ?>
            <div class="<?php echo (strpos($message, 'Error') !== false) ? 'error-message' : 'success-message'; ?>"><?php echo $message; ?></div>
        <?php endif; ?>
    </form>


    <h2>Saved Files:</h2>
    <ul id="fileList">
        <?php if (count($files) > 0) : ?>
            <?php foreach ($files as $file) : ?>
                <li>
                    <a href="?file=<?php echo urlencode($file); ?>">
                        <?php echo htmlspecialchars(str_replace('_', ' ', $file)); ?>
                    </a>
                     <button class="delete-btn" onclick="deleteFile('<?php echo htmlspecialchars($file); ?>')">Delete</button>
                </li>
            <?php endforeach; ?>
        <?php else : ?>
            <li>No files saved yet.</li>
        <?php endif; ?>
    </ul>

    <script>
          function deleteFile(filename) {
            if (confirm('Are you sure you want to delete ' + filename + '?')) {
                // Perform deletion via fetch
                 fetch('index.php?delete=' + filename, {
                    method: 'GET' // Use GET request for deletion
                    }).then(response => {
                    if(response.ok) {
                        return response.text();
                    } else {
                        throw new Error("Something wrong happened!")
                    }
                }).then(html => {
                    // We are replacing only the updated content not whole page
                    document.body.innerHTML = html;
                 }).catch(err => {
                     console.log("Something went wrong!");
                    console.error(err);
                 });
            }
        }

         function copyToClipboard(elementId, replaceUnderscores) {
            const element = document.getElementById(elementId);
            let text = element.value;

            if (replaceUnderscores && elementId === 'filename') {
                text = text.replace(/_/g, ' ');
            }

            navigator.clipboard.writeText(text)
                .then(() => {
                    alert('Copied to clipboard!');
                })
                .catch(err => {
                    console.error('Failed to copy: ', err);
                    alert('Failed to copy to clipboard.');
                });
        }

          function pasteFromClipboard(elementId) {
            const element = document.getElementById(elementId);

            navigator.clipboard.readText()
                .then(text => {
                    element.value = text; // Replace existing content
                })
                .catch(err => {
                    console.error('Failed to read clipboard contents: ', err);
                    alert('Failed to paste from clipboard.');
                });
        }


        const fileForm = document.getElementById('fileForm');

       // Handle form submission (save to server)
        fileForm.addEventListener('submit', function(event) {
            event.preventDefault(); // Prevent form from submitting the traditional way
            const formData = new FormData(this);

            fetch('index.php', {
                method: 'POST',
                body: formData
            }).then(response => {
               if(response.ok) {
                    return response.text();
                } else {
                    throw new Error("Something wrong happened!")
                }
             }).then(html => {
                // We are replacing only the updated content not whole page
                document.body.innerHTML = html;

             }).catch(err => {
                 console.log("Something went wrong!");
                console.error(err);
            });

        });

    </script>

</body>
</html>