<?php
// Get the data from the POST request
$data = json_decode(file_get_contents('php://input'), true);
$text = isset($data['text']) ? $data['text'] : null;
$apiKey = isset($data['xiapikey']) ? $data['xiapikey'] : null;
$narratorId = isset($data['narratorId']) ? $data['narratorId'] : 'bIHbv24MWmeRgasZH58o'; // Default ID

// Validate input
if (!$text) {
    header('Content-Type: application/json');
    http_response_code(400); // Bad Request
    echo json_encode(['error' => 'Text is required']);
    exit();
}

if (!$apiKey) {
    header('Content-Type: application/json');
    http_response_code(401); // Unauthorized
    echo json_encode(['error' => 'API key is required']);
    exit();
}

// API endpoint with dynamic narrator ID
$apiUrl = "https://api.us.elevenlabs.io/v1/text-to-speech/" . $narratorId. "/stream?";

//https://api.us.elevenlabs.io/v1/text-to-speech/duFCGH0J8QZQnVuFK6fp/stream

// Set up headers for the ElevenLabs API
$requestHeaders = [
    "Content-Type: application/json",
    "Accept: */*",
    "xi-api-key: $apiKey",
    "User-Agent: Mozilla/5.0 (Linux; Android 10; Zenfone Max Pro M1 Build/QQ3A.200805.001) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/100.0.4896.127 Mobile Safari/537.36"
];

// Set up the POST data
$postFields = json_encode([
    "text" => $text,
    "model_id" => "eleven_multilingual_v2"
]);

// Initialize cURL
$ch = curl_init();
curl_setopt($ch, CURLOPT_URL, $apiUrl);
curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
curl_setopt($ch, CURLOPT_HTTPHEADER, $requestHeaders);
curl_setopt($ch, CURLOPT_POST, true);
curl_setopt($ch, CURLOPT_POSTFIELDS, $postFields);

// Execute the request
$response = curl_exec($ch);
curl_close($ch);

// Check if response is JSON
$jsonResponse = json_decode($response, true);
if (json_last_error() === JSON_ERROR_NONE) {
    // JSON response detected - check for quota error
    if (isset($jsonResponse['detail']['status']) && $jsonResponse['detail']['status'] === 'quota_exceeded') {
        header('Content-Type: application/json');
        http_response_code(429); // Too Many Requests
        echo json_encode($jsonResponse);
        exit();
    }
}

// If the response is not JSON, assume it’s audio and return it
header('Content-Type: audio/mpeg');
http_response_code(200); // OK
echo $response;
?>
