<?php

$uploadDir = 'uploads'; // Directory to store files
if (!is_dir($uploadDir)) {
    mkdir($uploadDir, 0777, true);
}

// Handle file deletion
if ($_SERVER['REQUEST_METHOD'] === 'GET' && isset($_GET['delete'])) {
    $fileToDelete = $uploadDir . '/' . basename($_GET['delete']);
    if (file_exists($fileToDelete)) {
        if (unlink($fileToDelete)) {
            $message = "File '" . basename($_GET['delete']) . "' deleted successfully!";
        } else {
            $message = "Error deleting file.";
        }
    } else {
        $message = "File not found.";
    }
}

// Handle file saving
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['filename']) && isset($_POST['content'])) {
    $filename = trim($_POST['filename']);
    $content = $_POST['content'];

    // Basic sanitization
    $filename = preg_replace('/[^a-zA-Z0-9._-]/', '', $filename);

    if (!empty($filename) && !empty($content)) {
        $filepath = $uploadDir . '/' . $filename . '.txt'; // Add .txt extension

        if (file_put_contents($filepath, $content) !== false) {
            $message = "File '$filename.txt' saved successfully!";
        } else {
            $message = "Error saving file.";
        }
    } else {
        $message = "Filename and content cannot be empty";
    }
}

// Read the list of files and content if a file is selected
$files = [];
$selectedFileContent = '';
$selectedFileName = '';
if (is_dir($uploadDir)) {
    $filelist = glob($uploadDir . '/*.txt');
    if ($filelist) {
        foreach ($filelist as $file) {
            $files[] = basename($file);
        }
        if (isset($_GET['file'])) {
            $selectedFileName =  $_GET['file'];
            $selectedFile = $uploadDir . '/' . $_GET['file'];
            if (file_exists($selectedFile)) {
                $selectedFileContent = htmlspecialchars(file_get_contents($selectedFile));
            }
        }
    }
}

?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Text File Manager</title>
    <style>
        body {
            font-family: sans-serif;
            background-color: #f0f8ff;
            color: #333;
            margin: 2px;
            padding: 2px;
            display: flex;
            flex-direction: column;
            align-items: center;
        }

        h1 {
            color: #4682b4;
            text-align: center;
            margin-bottom: 20px;
        }

        form {
            background-color: #fff;
            padding: 20px;
            border-radius: 8px;
            box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
            width: 80vw;
            margin-bottom: 20px;
            display: flex;
            flex-direction: column;
            align-items: center;
        }

        form > div {
            width: 100%;
            display: flex;
            flex-direction: column;
            margin-bottom: 10px;
        }

        label {
            display: block;
            margin-bottom: 5px;
            color: #333;
        }

        input[type="text"] {
            padding: 10px;
            border: 1px solid #ccc;
            border-radius: 4px;
            width: 80vw;
            margin-bottom: 10px;
            box-sizing: border-box;
        }

        textarea {
            width: 80vw;
            height: 60vh;
            padding: 10px;
            border: 1px solid #ccc;
            border-radius: 4px;
            box-sizing: border-box;
            margin-bottom: 10px;
            font-family: monospace;
            background-color: #f0f8ff;
            color: #000;
        }

        button {
            background-color: #4682b4;
            color: white;
            padding: 10px 15px;
            border: none;
            border-radius: 4px;
            cursor: pointer;
            transition: background-color 0.3s;
            margin: 5px 0px;
        }

        button:hover {
            background-color: #2e648c;
        }

        ul {
            list-style: none;
            padding: 0;
            width: 80%;
            max-width: 600px;
        }

        ul li {
            margin: 5px 0;
            padding: 8px;
            border-bottom: 1px solid #eee;
            border-radius: 4px;
            background-color: #fff;
            box-shadow: 0 1px 2px rgba(0, 0, 0, 0.05);
             display: flex;
            justify-content: space-between;
             align-items: center;

        }

        ul li a {
            text-decoration: none;
            color: #4682b4;
            display: block;
             flex-grow: 1;
        }

        ul li a:hover {
            color: #2e648c;
        }
        .error-message {
            color: red;
            margin-top: 10px;
            text-align: center;
        }

        .success-message {
            color: green;
            margin-top: 10px;
            text-align: center;
        }
        .delete-btn {
           background-color: #ff4d4d;
            color: white;
            padding: 6px 10px;
            border: none;
            border-radius: 4px;
            cursor: pointer;
            transition: background-color 0.3s;

        }
        .delete-btn:hover {
            background-color: #cc0000;
        }
    </style>
</head>
<body>

    <form id="fileForm" method="POST">
        <div>
            <label for="filename">File Name:</label>
            <input type="text" name="filename" id="filename" value="<?php echo htmlspecialchars(str_replace('.txt', '', $selectedFileName)); ?>" required>
        </div>
        <div>
            <label for="content">File Content:</label>
            <textarea name="content" id="content" required><?php echo $selectedFileContent ?></textarea>
        </div>
        <button type="submit">Save File</button>
        <?php if (isset($message)) : ?>
            <div class="<?php echo (strpos($message, 'Error') !== false) ? 'error-message' : 'success-message'; ?>"><?php echo $message; ?></div>
        <?php endif; ?>
    </form>


    <h2>Saved Files:</h2>
    <ul id="fileList">
        <?php if (count($files) > 0) : ?>
            <?php foreach ($files as $file) : ?>
                <li>
                    <a href="?file=<?php echo urlencode($file); ?>">
                        <?php echo htmlspecialchars($file); ?>
                    </a>
                     <button class="delete-btn" onclick="deleteFile('<?php echo htmlspecialchars($file); ?>')">Delete</button>
                </li>
            <?php endforeach; ?>
        <?php else : ?>
            <li>No files saved yet.</li>
        <?php endif; ?>
    </ul>

    <script>
          function deleteFile(filename) {
            if (confirm('Are you sure you want to delete ' + filename + '?')) {
                // Perform deletion via fetch
                 fetch('text.php?delete=' + filename, {
                    method: 'GET' // Use GET request for deletion
                    }).then(response => {
                    if(response.ok) {
                        return response.text();
                    } else {
                        throw new Error("Something wrong happened!")
                    }
                }).then(html => {
                    // We are replacing only the updated content not whole page
                    document.body.innerHTML = html;
                 }).catch(err => {
                     console.log("Something went wrong!");
                    console.error(err);
                 });
            }
        }

        document.getElementById('fileForm').addEventListener('submit', function(event) {
            event.preventDefault(); // Prevent form from submitting the traditional way
            const formData = new FormData(this);

            fetch('text.php', {
                method: 'POST',
                body: formData
            }).then(response => {
               if(response.ok) {
                    return response.text();
                } else {
                    throw new Error("Something wrong happened!")
                }
             }).then(html => {
                // We are replacing only the updated content not whole page
                document.body.innerHTML = html;

             }).catch(err => {
                 console.log("Something went wrong!");
                console.error(err);
            });

        });
    </script>
<br>
<br>
<br>
<br>
<br>
<br>
<br>
<br>
<br>
<br>
<br>
</body>
</html>